@@ -100,7 +100,15 @@ class TestPKConstants(TestCase):
     def test_constants13_3(self):
         self.assertIsInstance(PassKit.PKPaymentNetworkPostFinance, str)
 
+    @min_os_level("14.0")
+    def test_constants14_0(self):
+        self.assertIsInstance(PassKit.PKPaymentNetworkPagoBancomat, str)
+
     @min_os_level("12.2")
     def test_constants12_1(self):
         # SDK Says available in 10.1, but not available there
         self.assertIsInstance(PassKit.PKPaymentNetworkDankort, str)
+
+    @min_os_level("14.4")
+    def test_constants14_4(self):
+        self.assertIsInstance(PassKit.PKPaymentNetworkMeeza, str)
